==> chaos_chat_ui-0.0.3.tar.gz: lib/src/chat_input_toolbar.dart <==
part of chaos_chat_ui;

class ChatInputToolbar extends StatelessWidget {
  final TextEditingController controller;
  final TextStyle inputTextStyle;
  final bool isWeb;
  final InputDecoration inputDecoration;
  final TextCapitalization textCapitalization;
  final BoxDecoration inputContainerStyle;
  final List<Widget> leading;
  final List<Widget> trailling;
  final int inputMaxLines;
  final int maxInputLength;
  final bool alwaysShowSend;
  final ChatUser user;
  final Function(ChatMessage) onSend;
  final String text;
  final Function(String) onTextChange;
  final bool inputDisabled;
  final String Function() messageIdGenerator;
  final Widget Function(Function) sendButtonBuilder;
  final Widget Function() inputFooterBuilder;
  final bool showInputCursor;
  final double inputCursorWidth;
  final Color inputCursorColor;
  final ScrollController scrollController;
  final bool showTraillingBeforeSend;
  final FocusNode focusNode;
  final EdgeInsets inputToolbarPadding;
  final EdgeInsets inputToolbarMargin;
  final TextDirection textDirection;
  final bool sendOnEnter;
  final bool reverse;
  final TextInputAction textInputAction;

  ChatInputToolbar({
    Key key,
    this.textDirection = TextDirection.ltr,
    this.isWeb,
    this.focusNode,
    this.scrollController,
    this.text,
    this.textInputAction,
    this.sendOnEnter = false,
    this.onTextChange,
    this.inputDisabled = false,
    this.controller,
    this.leading = const [],
    this.trailling = const [],
    this.inputDecoration,
    this.textCapitalization,
    this.inputTextStyle,
    this.inputContainerStyle,
    this.inputMaxLines = 1,
    this.showInputCursor = true,
    this.maxInputLength,
    this.inputCursorWidth = 2.0,
    this.inputCursorColor,
    this.onSend,
    this.reverse = false,
    @required this.user,
    this.alwaysShowSend = false,
    this.messageIdGenerator,
    this.inputFooterBuilder,
    this.sendButtonBuilder,
    this.showTraillingBeforeSend = true,
    this.inputToolbarPadding = const EdgeInsets.all(0.0),
    this.inputToolbarMargin = const EdgeInsets.all(0.0),
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    ChatMessage message = ChatMessage(
      text: text,
      user: user,
      messageIdGenerator: messageIdGenerator,
      createdAt: DateTime.now(),
    );

    void handleKeyPress(event) {
      if (event is RawKeyUpEvent && event.data is RawKeyEventDataWeb) {
        var data = event.data as RawKeyEventDataWeb;
        if (data.code == "Enter" && !event.isShiftPressed) {
          final val = controller.value;
          final messageWithoutNewLine =
              controller.text.substring(0, val.selection.start - 1) +
                  controller.text.substring(val.selection.start);
          controller.value = TextEditingValue(
            text: messageWithoutNewLine,
            selection: TextSelection.fromPosition(
              TextPosition(offset: messageWithoutNewLine.length),
            ),
          );
          // _onSend();
          if(sendOnEnter) {
            _sendMessage(context , message);
          }
        }
      }
    }

    return Container(
      padding: inputToolbarPadding,
      margin: inputToolbarMargin,
      decoration: inputContainerStyle != null
          ? inputContainerStyle
          : BoxDecoration(color: Colors.white),
      child: Column(
        children: <Widget>[
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: <Widget>[
              ...leading,
              Expanded(
                child: Padding(
                  padding: const EdgeInsets.symmetric(horizontal: 8.0),
                  child:isWeb?
                  RawKeyboardListener(
                    focusNode: focusNode,
                    onKey: handleKeyPress,
                    child: Directionality(
                      textDirection: textDirection,
                      child: TextField(

                      //focusNode: focusNode,
                      onChanged: (value) {
                        onTextChange(value);
                      },
                      onSubmitted: (value) {
                        if(sendOnEnter){
                          _sendMessage(context, message);
                          }
                        },
                      textInputAction: textInputAction,
                      buildCounter: (
                          BuildContext context, {
                            int currentLength,
                            int maxLength,
                            bool isFocused,
                          }) =>
                      null,
                      decoration: inputDecoration != null
                          ? inputDecoration
                          : InputDecoration.collapsed(
                        hintText: "",
                        fillColor: Colors.white,
                      ),
                      textCapitalization: textCapitalization,
                      controller: controller,
                      style: inputTextStyle,
                      maxLength: maxInputLength,
                      minLines: 1,
                      maxLines: inputMaxLines,
                      showCursor: showInputCursor,
                      cursorColor: inputCursorColor,
                      cursorWidth: inputCursorWidth,
                      enabled: !inputDisabled,
                    )),
                  ):
                  Directionality(
                      textDirection: textDirection,
                      child: TextField(

                        focusNode: focusNode,
                        onChanged: (value) {
                          onTextChange(value);
                        },
                        onSubmitted: (value) {
                          if(sendOnEnter){
                            _sendMessage(context, message);
                          }
                        },
                        textInputAction: textInputAction,
                        buildCounter: (
                            BuildContext context, {
                              int currentLength,
                              int maxLength,
                              bool isFocused,
                            }) =>
                        null,
                        decoration: inputDecoration != null
                            ? inputDecoration
                            : InputDecoration.collapsed(
                          hintText: "",
                          fillColor: Colors.white,
                        ),
                        textCapitalization: textCapitalization,
                        controller: controller,
                        style: inputTextStyle,
                        maxLength: maxInputLength,
                        minLines: 1,
                        maxLines: inputMaxLines,
                        showCursor: showInputCursor,
                        cursorColor: inputCursorColor,
                        cursorWidth: inputCursorWidth,
                        enabled: !inputDisabled,
                      )),
                ),
              ),
              if (showTraillingBeforeSend) ...trailling,
              if (sendButtonBuilder != null)
                sendButtonBuilder(() async {
                  if (text.length != 0) {
                    await onSend(message);

                    controller.text = "";

                    onTextChange("");
                  }
                })
              else
                IconButton(
                  icon: Icon(Icons.send),
                  onPressed: alwaysShowSend || text.length != 0
                      ? () => _sendMessage(context, message)
                      : null,
                ),
              if (!showTraillingBeforeSend) ...trailling,
            ],
          ),
          if (inputFooterBuilder != null) inputFooterBuilder()
        ],
      ),
    );
  }

  void _sendMessage(BuildContext context, ChatMessage message) async {
    if (text.length != 0) {
      await onSend(message);

      controller.text = "";

      onTextChange("");

      FocusScope.of(context).requestFocus(focusNode);

      Timer(Duration(milliseconds: 150), () {
        scrollController.animateTo(
          reverse ? 0.0 : scrollController.position.maxScrollExtent + 30.0,
          curve: Curves.easeOut,
          duration: const Duration(milliseconds: 300),
        );
      });
    }
  }
}

==> chaos_chat_ui-0.0.5.tar.gz: lib/src/chat_input_toolbar.dart <==
part of chaos_chat_ui;
class EnterIntent extends Intent {
  const EnterIntent();
}
class ShiftIntent extends Intent {
  const ShiftIntent();
}
class ChatInputToolbar extends StatelessWidget {
  final TextEditingController controller;
  final TextStyle inputTextStyle;
  final bool isWeb;
  final InputDecoration inputDecoration;
  final TextCapitalization textCapitalization;
  final BoxDecoration inputContainerStyle;
  final List<Widget> leading;
  final List<Widget> trailling;
  final int inputMaxLines;
  final int maxInputLength;
  final bool alwaysShowSend;
  final ChatUser user;
  final Function(ChatMessage) onSend;
  final String text;
  final Function(String) onTextChange;
  final bool inputDisabled;
  final String Function() messageIdGenerator;
  final Widget Function(Function) sendButtonBuilder;
  final Widget Function() inputFooterBuilder;
  final bool showInputCursor;
  final double inputCursorWidth;
  final Color inputCursorColor;
  final ScrollController scrollController;
  final bool showTraillingBeforeSend;
  final FocusNode focusNode;
  final EdgeInsets inputToolbarPadding;
  final EdgeInsets inputToolbarMargin;
  final TextDirection textDirection;
  final bool sendOnEnter;
  final bool reverse;
  final TextInputAction textInputAction;

  ChatInputToolbar({
    Key key,
    this.textDirection = TextDirection.ltr,
    this.isWeb,
    this.focusNode,
    this.scrollController,
    this.text,
    this.textInputAction,
    this.sendOnEnter = false,
    this.onTextChange,
    this.inputDisabled = false,
    this.controller,
    this.leading = const [],
    this.trailling = const [],
    this.inputDecoration,
    this.textCapitalization,
    this.inputTextStyle,
    this.inputContainerStyle,
    this.inputMaxLines = 1,
    this.showInputCursor = true,
    this.maxInputLength,
    this.inputCursorWidth = 2.0,
    this.inputCursorColor,
    this.onSend,
    this.reverse = false,
    @required this.user,
    this.alwaysShowSend = false,
    this.messageIdGenerator,
    this.inputFooterBuilder,
    this.sendButtonBuilder,
    this.showTraillingBeforeSend = true,
    this.inputToolbarPadding = const EdgeInsets.all(0.0),
    this.inputToolbarMargin = const EdgeInsets.all(0.0),
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    controller.selection = TextSelection.fromPosition(TextPosition(offset: controller.text.length));
    String nextline='\n';
    ChatMessage message = ChatMessage(
      text: text,
      user: user,
      messageIdGenerator: messageIdGenerator,
      createdAt: DateTime.now(),
    );


    return Container(
      padding: inputToolbarPadding,
      margin: inputToolbarMargin,
      decoration: inputContainerStyle != null
          ? inputContainerStyle
          : BoxDecoration(color: Colors.white),
      child: Column(
        children: <Widget>[
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: <Widget>[
              ...leading,
              Expanded(
                child: Padding(
                  padding: const EdgeInsets.symmetric(horizontal: 8.0),
                  child:isWeb?
                  Shortcuts(
                    shortcuts: <LogicalKeySet, Intent>{
                      LogicalKeySet(LogicalKeyboardKey.enter): const EnterIntent(),
                      LogicalKeySet(LogicalKeyboardKey.shift , LogicalKeyboardKey.enter): const ShiftIntent(),
                    },
                    child: Actions(
                      actions: <Type, Action<Intent>>{

                        EnterIntent: CallbackAction<EnterIntent>(
                          onInvoke: (EnterIntent intent) => {
                            if(text.length!=0){
                              _sendMessage(context , message) ,
                              controller..text = ""
                            }
                          }
                        ),
                        ShiftIntent:CallbackAction<ShiftIntent>(
                            onInvoke: (ShiftIntent intent) => {
                              controller..text='${controller.text}$nextline',
                              controller.selection = TextSelection.fromPosition(TextPosition(offset: controller.text.length))
                            }
                        ),
                      },
                      child: Directionality(
                        textDirection: textDirection,
                        child: TextField(
                          autofocus: true,
                        focusNode: focusNode,
                        onChanged: (value) {
                          onTextChange(value);
                        },
                        onSubmitted: (value) {
                          if(sendOnEnter){
                            _sendMessage(context, message);
                            }
                          },
                        textInputAction: textInputAction,
                        buildCounter: (
                            BuildContext context, {
                              int currentLength,
                              int maxLength,
                              bool isFocused,
                            }) =>
                        null,
                        decoration: inputDecoration != null
                            ? inputDecoration
                            : InputDecoration.collapsed(
                          hintText: "",
                          fillColor: Colors.white,
                        ),
                        textCapitalization: textCapitalization,
                        controller: controller,
                        style: inputTextStyle,
                        maxLength: maxInputLength,
                        minLines: 1,
                        maxLines: inputMaxLines,
                        showCursor: showInputCursor,
                        cursorColor: inputCursorColor,
                        cursorWidth: inputCursorWidth,
                        enabled: !inputDisabled,
                      )),
                    ),
                  ):
                  Directionality(
                      textDirection: textDirection,
                      child: TextField(

                        focusNode: focusNode,
                        onChanged: (value) {
                          onTextChange(value);
                        },
                        onSubmitted: (value) {
                          if(sendOnEnter){
                            _sendMessage(context, message);
                          }
                        },
                        textInputAction: textInputAction,
                        buildCounter: (
                            BuildContext context, {
                              int currentLength,
                              int maxLength,
                              bool isFocused,
                            }) =>
                        null,
                        decoration: inputDecoration != null
                            ? inputDecoration
                            : InputDecoration.collapsed(
                          hintText: "",
                          fillColor: Colors.white,
                        ),
                        textCapitalization: textCapitalization,
                        controller: controller,
                        style: inputTextStyle,
                        maxLength: maxInputLength,
                        minLines: 1,
                        maxLines: inputMaxLines,
                        showCursor: showInputCursor,
                        cursorColor: inputCursorColor,
                        cursorWidth: inputCursorWidth,
                        enabled: !inputDisabled,
                      )),
                ),
              ),
              if (showTraillingBeforeSend) ...trailling,
              if (sendButtonBuilder != null)
                sendButtonBuilder(() async {
                  if (text.length != 0)  {
                    await onSend(message);

                    controller.text = "";

                    onTextChange("");
                  }
                })
              else
                IconButton(
                  icon: Icon(Icons.send),
                  onPressed: alwaysShowSend || text.length != 0
                      ? () => _sendMessage(context, message)
                      :null,
                ),
              if (!showTraillingBeforeSend) ...trailling,
            ],
          ),
          if (inputFooterBuilder != null) inputFooterBuilder()
        ],
      ),
    );
  }

  void _sendMessage(BuildContext context, ChatMessage message) async {
    if (text.length != 0 ) {
      await onSend(message);

      controller.text = "";

      onTextChange("");

      FocusScope.of(context).requestFocus(focusNode);

      Timer(Duration(milliseconds: 150), () {
        scrollController.animateTo(
          reverse ? 0.0 : scrollController.position.maxScrollExtent + 30.0,
          curve: Curves.easeOut,
          duration: const Duration(milliseconds: 300),
        );
      });
    }
  }
}
